@@ -1,8 +1,7 @@
-
+import os
 import numpy as np
 from osgeo import ogr, osr, gdal
 from shapely.wkt import loads
-
 from pyflowline.formats.convert_coordinates import convert_gcs_coordinates_to_flowline
 
 def read_nhdplus_flowline_shapefile_attribute(sFilename_shapefile_in):
@@ -11,6 +10,14 @@ def read_nhdplus_flowline_shapefile_attribute(sFilename_shapefile_in):
     This function should be used for stream flowline only.
     """
 
+    iReturn_code = 1
+    if os.path.isfile(sFilename_shapefile_in):
+        pass
+    else:
+        print('This shapefile does not exist: ', sFilename_shapefile_in )
+        iReturn_code = 0
+        return iReturn_code
+
     #aFromNode=list()
     #aToNode=list()
     aNHDPlusID=list()
@@ -45,8 +52,27 @@ def read_nhdplus_flowline_shapefile_attribute(sFilename_shapefile_in):
     return aNHDPlusID
 
 def extract_nhdplus_flowline_shapefile_by_attribute(sFilename_shapefile_in, aAttribute_in):
+    """_summary_
+
+    Args:
+        sFilename_shapefile_in (_type_): _description_
+        aAttribute_in (_type_): _description_
+
+    Returns:
+        _type_: _description_
+    """
+
+    iReturn_code = 1
+
+    if os.path.isfile(sFilename_shapefile_in):
+        pass
+    else:
+        print('This shapefile does not exist: ', sFilename_shapefile_in )
+        iReturn_code = 0
+        return iReturn_code
+
     aFlowline =list()
-    #pDriver_json = ogr.GetDriverByName('GeoJSON')
+
     pDriver_shapefile = ogr.GetDriverByName('ESRI Shapefile')
    
     pDataset_shapefile = pDriver_shapefile.Open(sFilename_shapefile_in, gdal.GA_ReadOnly)
